import { query } from '@/modules/query';
import { message } from '@kevisual/system-ui/dist/message';
import { create } from 'zustand';

export interface FormData {
  id: string;
  title: string;
  description: string;
  link: string;
  tags: string[];
}

type DevStore = {
  list: any[];
  setList: (list: any[]) => void;
  getList: () => Promise<void>;
  updateData: (data: any) => Promise<any>;
  getOne: (id: string) => Promise<void>;
  formData: any;
  setFormData: (data: any) => void;
  deleteOne: (id: string) => Promise<boolean>;
};
export const useDevStore = create<DevStore>((set) => ({
  list: [],
  setList: (list) => set({ list }),
  formData: {},
  setFormData: (data) => set({ formData: data }),
  getList: async () => {
    const res = await query.post({
      path: 'dev-app',
      key: 'list',
    });
    console.log(res);
    if (res.success) {
      set({ list: res.data });
    }
  },
  updateData: async (data) => {
    const res = await query.post({
      path: 'dev-app',
      key: 'update',
      data,
    });
    if (res.code === 200) {
      // set({ formData: {} });
      message.success('更新成功');
    }
  },
  getOne: async (id) => {
    const res = await query.post({
      path: 'dev-app',
      key: 'get',
      id,
    });
    if (res.code === 200) {
      set({ formData: res.data });
    }
  },
  deleteOne: async (id) => {
    const res = await query.post({
      path: 'dev-app',
      key: 'delete',
      id,
    });
    if (res.code === 200) {
      message.success('删除成功');
      return true;
    }
    return false;
  },
}));
