import { build } from 'esbuild';
import { writeFileSync } from 'fs';
import { resolve } from 'path';

export async function transformToMJS(inputCode) {
  // 1. 使用 esbuild 转换代码
  const result = await build({
    stdin: {
      contents: inputCode,
      resolveDir: process.cwd(), // 当前目录为基准路径，用于解析文件路径
      loader: 'ts',
    },
    format: 'esm', // 输出为 ESM 格式
    outfile: 'output.mjs', // 输出文件路径
    write: false, // 不直接写入文件
  });

  // 2. 将结果保存为 .mjs 文件
  const outputPath = resolve('./output.mjs');
  writeFileSync(outputPath, result.outputFiles[0].text);

  console.log(`转换完成，文件已保存到: ${outputPath}`);
  return outputPath;
}

// 示例字符串代码
const inputCode = `
import path from 'path';
import {nanoid} from 'nanoid';
console.log(path.resolve(), nanoid(6));
`;

const runCode = (filePath: string) => {
  const mjs = import(filePath);
  //
};
transformToMJS(inputCode)
  .then((outputPath) => {
    console.log(`生成的 MJS 文件路径: ${outputPath}`);
    runCode(outputPath);
  })
  .catch(console.error);
