// 获取文件的
import { app } from '@/app.ts';
import { DevModel } from './model.ts';
import { md5 } from '@/modules/md5.ts';
import { createCodePath } from '@/modules/manager.ts';

app
  .route({
    path: 'dev-app',
    key: 'list',
    description: '获取开发配置列表',
  })
  .define(async (ctx) => {
    const list = await DevModel.findAll({
      logging: false,
    });
    ctx.body = list;
  })
  .addTo(app);

app
  .route({
    path: 'dev-app',
    key: 'update',
    description: '更新开发配置',
  })
  .define(async (ctx) => {
    const data = ctx.query.data || {};
    const id = data.id;
    let dev: DevModel;
    let hashChange = false || !!ctx.query.force;
    if (id) {
      dev = await DevModel.findByPk(id);
      if (!dev) {
        ctx.throw(404, 'dev not found');
        return;
      }
      const updateData = {
        ...dev.data,
        ...data?.data,
      };
      console.log('updateData', updateData);
      if (updateData?.code) {
        const codeHash = md5(updateData.code);
        if (codeHash !== dev.data.codeHash) {
          updateData.codeHash = codeHash;
          updateData.codePath = '';
          hashChange = true;
        }
      }
      await dev.update(
        {
          title: dev.title,
          description: dev.description,
          data: updateData,
        },
        {
          logging: false,
          fields: ['title', 'key', 'description', 'data'],
        },
      );
    } else {
      const updateData = {
        ...data?.data,
      };
      if (updateData?.code) {
        const codeHash = md5(updateData.code);
        updateData.codeHash = codeHash;
        updateData.codePath = '';
        hashChange = true;
      }
      dev = await DevModel.create({
        ...updateData,
      });
    }
    if (hashChange && dev.data?.status === 'active') {
      await createCodePath(dev);
    }
    ctx.body = dev;
  })
  .addTo(app);

app
  .route({
    path: 'dev-app',
    key: 'delete',
    description: '删除开发配置',
  })
  .define(async (ctx) => {
    const id = ctx.query.id;
    if (!id) {
      ctx.throw(400, 'id is required');
      return;
    }
    const dev = await DevModel.findByPk(id);
    if (!dev) {
      ctx.throw(404, 'dev not found');
      return;
    }
    await dev.destroy({
      logging: false,
    });
    ctx.body = 'ok';
  })
  .addTo(app);


