import { DataTypes, Model, Op } from 'sequelize';
import { sequelize } from '@/modules/sequelize.ts';

type SSHModelData = {
  localPort: number;
  remoteHost: string; // localhost
  remotePort: number;
  status?: 'active' | 'inactive';
};
export type SSH = Partial<InstanceType<typeof SSHModel>>;

export class SSHModel extends Model {
  declare id: string;
  // declare title: string;
  declare description: string;
  declare configs: SSHModelData[];
  declare remote: string;
}
SSHModel.init(
  {
    id: {
      type: DataTypes.UUID,
      primaryKey: true,
      defaultValue: DataTypes.UUIDV4,
    },
    // title: {
    //   type: DataTypes.TEXT,
    //   allowNull: false,
    //   defaultValue: '',
    // },
    description: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    configs: {
      type: DataTypes.JSON,
      allowNull: false,
      defaultValue: [],
    },
    remote: {
      type: DataTypes.TEXT,
      allowNull: false,
      defaultValue: '',
    },
  },
  {
    sequelize,
    paranoid: true,
    modelName: 'local_ssh',
    freezeTableName: true, // 禁用表名复数化
  },
);

SSHModel.sync({
  alter: true,
  logging: false,
}).catch((e) => {
  console.error(e);
});
