import { app } from '@/app.ts';
import { SSHModel } from './model.ts';
import { sshManager } from '@/lib/ssh.ts';
import { exec } from 'child_process';

const init = async () => {
  const sshList = await SSHModel.findAll();
  sshList.forEach((ssh) => {
    sshManager.createServer(ssh.remote, ssh.configs);
  });
};
try {
  if (!DEV_SERVER) {
    setTimeout(init, 1000);
  }
} catch (e) {}
app
  .route({
    path: 'ssh',
    key: 'list',
  })
  .define(async (ctx) => {
    const sshList = await SSHModel.findAll();
    ctx.body = sshList;
  })
  .addTo(app);

app
  .route({
    path: 'ssh',
    key: 'status',
  })
  .define(async (ctx) => {
    ctx.body = sshManager.getServers();
  })
  .addTo(app);
app
  .route({
    path: 'ssh',
    key: 'update',
  })
  .define(async (ctx) => {
    const data = ctx.query.data;
    const isExec = ctx.query.exec ?? true;
    const { description, configs, remote } = data;
    if (!remote) {
      ctx.throw(400, 'remote 不能为空');
    }
    let ssh = await SSHModel.findOne({ where: { remote } });
    if (!ssh) {
      ssh = await SSHModel.create({ description, configs, remote });
    }
    await ssh.update({ description, configs }, { where: { remote } });
    //
    if (isExec) {
      sshManager.createServer(remote, configs);
    }

    ctx.body = ssh;
  })
  .addTo(app);

app
  .route({
    path: 'ssh',
    key: 'closePort',
  })
  .define(async (ctx) => {
    const port = ctx.query.port;
    if (!port) {
      ctx.throw(400, 'port 不能为空');
    }

    exec(`lsof -i:${port} | grep LISTEN | awk '{print $2}' | xargs kill -9`, (killErr, stdout, stderr) => {
      if (killErr) {
        console.error(`Failed to kill process on port ${port}:`, killErr.message);
      } else {
        console.log(`Port ${port} is now free. Restarting process...`);
      }
    });
    ctx.body = 'ok';
  })
  .addTo(app);
